import Vue from "vue";
import VueRouter from "vue-router";
import Layouts from "@/layouts/Layouts.vue";
import store from "@/store";
// import local from "@/utils/local";
// 解决重复点击同一个路由报错
const originalPush = VueRouter.prototype.push;
VueRouter.prototype.push = function (location) {
  return originalPush.call(this, location).catch((err) => err);
};
Vue.use(VueRouter);
/**
 *  Route 对象配置:
 * hidden：控制路由是否显示在在菜单
 * hideChildrenInMenu:强制菜单显示为Item而不是SubItem
 * meta对象配置:
 * title:标题
 * keepAlive:缓存该路由
 * activeMenu:当前的激活路由
 * icon:图标
 * hidden：控制路由是否显示在在菜单
 */
const routes = [
  {
    path: "/",
    component: Layouts,
    redirect: "/sso",
    children: [
      {
        path: "/home",
        hideChildrenInMenu: true,
        component: () => import("@/pages/home/Home"),
        meta: {
          icon: "el-icon-house",
          title: "数仓工作台",
        },
      },
      {
        path: "/engine",
        hideChildrenInMenu: true,
        component: () => import("@/pages/engine/Engine"),
        meta: {
          icon: "el-icon-cpu",
          title: "数据引擎",
        },
      },
      {
        path: "/market",
        hideChildrenInMenu: true,
        component: () => import("@/pages/market/Market"),
        meta: {
          icon: "el-icon-office-building",
          title: "数据集市",
        },
      },
      {
        path: "/system",
        hideChildrenInMenu: true,
        component: () => import("@/pages/system/System"),
        meta: {
          icon: "el-icon-setting",
          title: "系统设置",
        },
      },
    ],
  },
  {
    path: "/sso",
    name: "跳转页",
    hidden: true,
    component: () => import("@/pages/sso/Sso"),
  },
  {
    path: "/login",
    name: "登录页",
    hidden: true,
    component: () => import("@/pages/login/Login"),
  },
];

const router = new VueRouter({
  routes,
});

// 前置路由卫士
// router.beforeEach((to, from, next) => {
//   let islogin = store.getters["user/token"];
//   if (islogin) {
//     next();
//   } else {
//     if (to.path === "/sso") {
//       next();
//     } else {
//       location.href = process.env.VUE_APP_API_portal_URL;
//     }
//   }
// });

// 过滤菜单
function menusFilter(arr) {
  let router = arr.filter((v) => {
    if (!v.hidden) {
      if (v.children) {
        v.children = menusFilter(v.children);
      }
      return v;
    }
  });
  return router;
}
// 动态菜单
export function calcMenu() {
  // dynamicRouter.forEach((v) => {
  //   router.addRoute(v);
  // });
  let menus = menusFilter(routes[0].children);
  store.commit("user/SET_menus", menus);
}
calcMenu();

export default router;
